@@ -14,48 +14,73 @@
 #                                                                     #
 #######################################################################
 ##' @title Plot an lcc object
-##' 
-##' @description A plot of predictions versus the time covariate is generated. Predicted values are joined by lines while sampled observations are represented by circles. If the argument \code{components=TRUE} is considered in the \code{lcc} object, single plots of each statistics are returned on differents pages.           
+##'
+##' @description A plot of predictions versus the time covariate is
+##'   generated. Predicted values are joined by lines while sampled
+##'   observations are represented by circles. If the argument
+##'   \code{components=TRUE} is considered in the \code{lcc} object,
+##'   single plots of each statistics are returned on differents pages.
 ##'
 ##' @usage
-##' lccPlot(obj, control, ...)
-##'     
-##' @param obj an object inheriting from class "lcc", representing a fitted lcc model.
-##' 
-##' @param control a list of control values or character strings returned by the function \code{\link{plotControl}}. Defaults to an empty list.  The list may contain the following components:
-##' \describe{
-##' \item{\code{shape}:}{draw points considering a shape parameter. Possible shape values are the numbers 0 to 25, and 32 to 127; see \code{\link[ggplot2]{aes_linetype_size_shape}}. Default is \code{1}.}
+##' lccPlot(obj, type, control, ...)
 ##'
-##' \item{\code{colour}:}{specification for lines color. Default is \code{"black"}.}
+##' @param obj an object inheriting from class "lcc", representing a
+##'   fitted lcc model.
 ##'
-##' \item{\code{size}:}{specification for lines size. Should be specified with a numerical value (in millimetres); see \code{\link[ggplot2]{aes_linetype_size_shape}}. Default is \code{0.5}.}
+##' @param type character string. If \code{type = "lcc"}, the output is
+##'   the LCC plot; if \code{type = "lpc"}, the output is the LPC plot;
+##'   and if \code{type = "la"} the output is the LA plot. Types "lpc"
+##'   and "la" are available only if \code{components = TRUE}.
 ##'
-##' \item{\code{xlab}:}{title for the \code{x} axis.  Default is \code{"Time"}.}
+##' @param control a list of control values or character strings
+##'   returned by the function \code{\link{plotControl}}. Defaults to an
+##'   empty list.  The list may contain the following components:
+##'   \describe{ \item{\code{shape}:}{draw points considering a shape
+##'   parameter. Possible shape values are the numbers 0 to 25, and 32
+##'   to 127; see
+##'   \code{\link[ggplot2]{aes_linetype_size_shape}}. Default is
+##'   \code{1}.}
 ##'
-##' \item{\code{LCC_ylab}:}{title for the \code{y} axis related with LCC. Default is \code{"LCC"}.}
+##' \item{\code{colour}:}{specification for lines color. Default is
+##' \code{"black"}.}
 ##'
-##' \item{\code{LPC_ylab}:}{title for the \code{y} axis related with LPC. Default is \code{"LPC"}.}
+##' \item{\code{size}:}{specification for lines size. Should be
+##' specified with a numerical value (in millimetres); see
+##' \code{\link[ggplot2]{aes_linetype_size_shape}}. Default is
+##' \code{0.5}.}
 ##'
-##' \item{\code{LA_ylab}:}{title for the \code{y} axis related with LA. Default is \code{"LA"}.}
+##' \item{\code{xlab}:}{title for the \code{x} axis.  Default is
+##' \code{"Time"}.}
 ##'
-##' \item{\code{LCC_scale_y_continuous}:}{numeric vector of length two providing limits of the scale related to LCC. Default is \code{c(0,1)}.}
+##' \item{\code{ylab}:}{title for the \code{y} axis. Default is "LCC",
+##' "LPC", or "LA"}
 ##'
-##' \item{\code{LPC_scale_y_continuous}:}{numeric vector of length two providing limits of the scale related to LPC. Default is \code{c(0,1)}.}
+##' \item{\code{scale_y_continuous}:}{numeric vector of length two
+##' providing limits of the scale. Default is
+##' \code{c(0,1)}.}
 ##'
-##' \item{\code{LA_scale_y_continuous}:}{numeric vector of length two providing limits of the scale related to LA. Default is \code{c(0,1)}.}
+##' \item{\code{all.plot}:}{\code{viewport} functions for the \code{lcc}
+##' class. If \code{TRUE}, the default, returns an object created by the
+##' \code{\link[grid]{viewport}} function with multiple plots on a
+##' single page. If \code{FALSE} returns a single
+##' \code{\link[ggplot2]{ggplot}} object by different pages using the
+##' \code{\link[gridExtra]{marrangeGrob}} function.}}
 ##'
-##' \item{\code{all.plot}:}{\code{viewport} functions for the \code{lcc} class. If \code{TRUE}, the default, returns an object created by the \code{\link[grid]{viewport}} function with multiple plots on a single page. If \code{FALSE} returns a single \code{\link[ggplot2]{ggplot}} object by different pages.}
-##' }
-##' 
 ##' @param ... not used.
-##' 
+##'
 ##' @author Thiago de Paula Oliveira, \email{thiago.paula.oliveira@@usp.br}
-##' 
-##' @references Lin, L. A Concordance Correlation Coefficient to Evaluate Reproducibility. \emph{Biometrics}, 45, n. 1, 255-268, 1989. 
-##' @references Oliveira, T.P.; Hinde, J.; Zocchi S.S. Longitudinal Concordance Correlation Function Based on Variance Components: An Application in Fruit Color Analysis. \emph{Journal of Agricultural, Biological, and Environmental Statistics}, v. 23, n. 2, 233–254, 2018.
-##' 
+##'
+##' @references Lin, L. A Concordance Correlation Coefficient to
+##'   Evaluate Reproducibility. \emph{Biometrics}, 45, n. 1, 255-268,
+##'   1989.
+##' @references Oliveira, T.P.; Hinde, J.; Zocchi S.S. Longitudinal
+##'   Concordance Correlation Function Based on Variance Components: An
+##'   Application in Fruit Color Analysis. \emph{Journal of
+##'   Agricultural, Biological, and Environmental Statistics}, v. 23,
+##'   n. 2, 233–254, 2018.
+##'
 ##' @seealso \code{\link[lcc]{lcc}}.
-##' 
+##'
 ##' @examples
 ##'
 ##' data(hue)
@@ -64,21 +89,35 @@
 ##' fm1<-lcc(dataset = hue, subject = "Fruit", resp = "H_mean",
 ##'          method = "Method", time = "Time", qf = 2, qr = 2,
 ##'          components=TRUE)
-##' lccPlot(fm1)
-##'          
+##' lccPlot(fm1, type="lcc")
+##' lccPlot(fm1, type="lpc")
+##' lccPlot(fm1, type="la")
+##'
+##' @examples
+##' ## Runing all.plots = FALSE and saving plots as pdf
+##' \dontrun{
+##' data(simulated_hue_block)
+##' attach(simulated_hue_block)
+##' fm2<-lcc(dataset = simulated_hue_block, subject = "Fruit",
+##'          resp = "Hue", method = "Method",time = "Time",
+##'          qf = 2, qr = 1, components = TRUE, covar = c("Block"),
+##'          time_lcc = list(n=50, from=min(Time), to=max(Time)))
+##' ggsave("myplots.pdf",
+##'        lccPlot(fm2, type="lcc", control=list(all.plot=FALSE)))
+##' }
 ##' @export
 
-lccPlot<-function(obj, control = list(), ...){
-  if(class(obj)!="lcc") stop("Object must inherit from class \"lcc\"", call.=FALSE) 
+lccPlot<-function(obj, type = "lcc", control = list(), ...){
+  if(class(obj)!="lcc") stop("Object must inherit from class \"lcc\"",
+                             call.=FALSE)
   # Arguments for the plot
   plot.cons<-plotControl(shape=1, colour="black",
     size=0.5, xlab = "Time",
-    LCC_ylab = "LCC", LPC_ylab = "LPC",
-    LA_ylab = "LA",
-    LCC_scale_y_continuous=c(0,1),
-    LPC_scale_y_continuous=c(0,1),
-    LA_scale_y_continuous=c(0,1),
+    ylab = "LCC",
+    scale_y_continuous=c(0,1),
     all.plot = TRUE)
+  if (type == "lpc") plot.cons$ylab = "LPC"
+  if (type == "la") plot.cons$ylab = "LA"
   if(length(control)){
     nms <- names(control)
     if (!is.list(control) || is.null(nms))
@@ -95,7 +134,7 @@ lccPlot<-function(obj, control = list(), ...){
       plot.cons[[pos[i]]]<-control[[i]]
     }
   }
-  
+
 
   #Standard arguments
   nd<-obj$plot_info$nd
@@ -105,46 +144,68 @@ lccPlot<-function(obj, control = list(), ...){
   ldb<-obj$plot_info$ldb
   ci<-obj$plot_info$ci
   components<-obj$plot_info$components
-  
+  if (components == FALSE &  type != "lcc") {
+    stop("'lpc' and 'la' plots only if components is TRUE",
+         call.= FALSE)
+  }
+  #---------------------------------------------------------------------
     if(ci==FALSE) {
       if(ldb == 1) {
+        if (type == "lcc") {
           plot_lcc(rho=obj$plot_info$rho, tk.plot= tk.plot,
             tk.plot2=tk.plot2, ldb=ldb,
             model=model, ci = ci,
             arg=plot.cons)
+        }
         if(components==TRUE){
+          if (type == "lpc") {
             plot_lpc(LPC=obj$plot_info$rho.pearson, tk.plot= tk.plot,
               tk.plot2=tk.plot2, ldb=ldb,
               model=model, ci = ci, arg = plot.cons)
+          }
+          if (type == "la") {
             plot_la(Cb=obj$plot_info$Cb, tk.plot= tk.plot,
               tk.plot2=tk.plot2, ldb=ldb,
               model=model, ci = ci, arg = plot.cons)
-        }
+          }
+         }
       } else {
+         if (type == "lcc") {
           plot_lcc(rho=obj$plot_info$rho, tk.plot= tk.plot,
             tk.plot2=tk.plot2, ldb=ldb, model=model,
             ci = ci, arg = plot.cons)
-        if(components==TRUE){
+          }
+         if(components==TRUE){
+           if (type == "lpc") {
             plot_lpc(LPC=obj$plot_info$rho.pearson, tk.plot= tk.plot,
               tk.plot2=tk.plot2, ldb=ldb, model=model,
               ci = ci, arg = plot.cons)
+           }
+           if (type == "la") {
             plot_la(Cb=obj$plot_info$Cb, tk.plot= tk.plot,
               tk.plot2=tk.plot2, ldb=ldb, model=model,
               ci = ci, arg = plot.cons)
-        }
+           }
+          }
       }
     }else{
       ENV.LCC<-obj$plot_info$ENV.LCC
+      if (type == "lcc") {
         plot_lcc(rho=obj$plot_info$rho, ENV.LCC=ENV.LCC, tk.plot= tk.plot,
           tk.plot2=tk.plot2, ldb=ldb, model=model,
           ci = ci, arg = plot.cons)
-        if(components==TRUE){
+        }
+      if(components==TRUE){
+        if (type == "lpc") {
         ENV.LPC<-obj$plot_info$ENV.LPC
-        ENV.Cb<-obj$plot_info$ENV.LA
         plot_lpc(LPC=obj$plot_info$rho.pearson,ENV.LPC=ENV.LPC, tk.plot= tk.plot,
           tk.plot2=tk.plot2, ldb=ldb, model=model, ci = ci, arg = plot.cons)
+        }
+        if (type == "la") {
+        ENV.Cb<-obj$plot_info$ENV.LA
         plot_la(Cb=obj$plot_info$Cb,ENV.Cb = ENV.Cb, tk.plot= tk.plot,
           tk.plot2=tk.plot2, ldb=ldb, model=model, ci = ci, arg = plot.cons)
         }
+       }
     }
-}
\ No newline at end of file
+}
